@@ -2,7 +2,7 @@
  *
  * This file is part of the GNOME Devtools Libraries.
  *
- * Copyright (C) 2002 Gustavo Girldez <gustavo.giraldez@gmx.net>
+ * Copyright (C) 2002 Gustavo Giráldez <gustavo.giraldez@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,12 +20,16 @@
  * Boston, MA 02111-1307, USA.  
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "gdl-i18n.h"
 #include <string.h>
 #include <stdlib.h>
 #include <libxml/parser.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgnome/gnome-macros.h>
 
 #include "gdl-dock-layout.h"
 #include "gdl-tools.h"
@@ -54,6 +58,8 @@ enum {
     COLUMN_ITEM
 };
 
+#define COLUMN_EDITABLE COLUMN_SHOW
+
 struct _GdlDockLayoutPrivate {
     xmlDocPtr         doc;
 
@@ -63,9 +69,6 @@ struct _GdlDockLayoutPrivate {
 
     /* idle control */
     gboolean          idle_save_pending;
-
-    /* ui change control */
-    gboolean          changed_by_user;
 };
 
 typedef struct _GdlDockLayoutUIData GdlDockLayoutUIData;
@@ -73,7 +76,6 @@ typedef struct _GdlDockLayoutUIData GdlDockLayoutUIData;
 struct _GdlDockLayoutUIData {
     GdlDockLayout    *layout;
     
-    GtkWidget        *layout_entry;
     GtkWidget        *locked_check;
     GtkTreeSelection *selection;
 };
@@ -102,10 +104,12 @@ static void     gdl_dock_layout_build_doc       (GdlDockLayout      *layout);
 static xmlNodePtr gdl_dock_layout_find_layout   (GdlDockLayout      *layout, 
                                                  const gchar        *name);
 
+static void     gdl_dock_layout_build_models    (GdlDockLayout      *layout);
+
 
 /* ----- Private implementation ----- */
 
-GNOME_CLASS_BOILERPLATE (GdlDockLayout, gdl_dock_layout, GObject, G_TYPE_OBJECT);
+GDL_CLASS_BOILERPLATE (GdlDockLayout, gdl_dock_layout, GObject, G_TYPE_OBJECT);
 
 static void
 gdl_dock_layout_class_init (GdlDockLayoutClass *klass)
@@ -140,6 +144,8 @@ gdl_dock_layout_instance_init (GdlDockLayout *layout)
     layout->dirty = FALSE;
     layout->_priv = g_new0 (GdlDockLayoutPrivate, 1);
     layout->_priv->idle_save_pending = FALSE;
+
+    gdl_dock_layout_build_models (layout);
 }
 
 static void
@@ -276,7 +282,8 @@ gdl_dock_layout_build_models (GdlDockLayout *layout)
     }
 
     if (!layout->_priv->layouts_model) {
-        layout->_priv->layouts_model = gtk_list_store_new (1, G_TYPE_STRING);
+        layout->_priv->layouts_model = gtk_list_store_new (2, G_TYPE_STRING,
+                                                           G_TYPE_BOOLEAN);
         gtk_tree_sortable_set_sort_column_id (
             GTK_TREE_SORTABLE (layout->_priv->layouts_model),
             COLUMN_NAME, GTK_SORT_ASCENDING);
@@ -284,53 +291,89 @@ gdl_dock_layout_build_models (GdlDockLayout *layout)
 }
 
 static void
-gdl_dock_layout_update_items_model (GdlDockLayout *layout)
+build_list (GdlDockObject *object, GList **list)
 {
-    GtkTreeIter iter;
-    
-    g_return_if_fail (layout != NULL && layout->_priv != NULL);
-    g_return_if_fail (layout->master != NULL);
-    g_return_if_fail (layout->_priv->items_model != NULL);
-
-    /* update items model data after a layout load */
-    if (gtk_tree_model_get_iter_root (
-        GTK_TREE_MODEL (layout->_priv->items_model), &iter)) {
-        do {
-            GdlDockItem *item;
-            gboolean     locked;
-            
-            gtk_tree_model_get (GTK_TREE_MODEL (layout->_priv->items_model), &iter,
-                                COLUMN_ITEM, &item,
-                                -1);
-            if (item) {
-                g_object_get (item, "locked", &locked, NULL);
-                
-                gtk_list_store_set (layout->_priv->items_model, &iter, 
-                                    COLUMN_SHOW, GDL_DOCK_OBJECT_ATTACHED (item),
-                                    COLUMN_LOCKED, locked,
-                                    -1);
-            };
-        } while (gtk_tree_model_iter_next (
-            GTK_TREE_MODEL (layout->_priv->items_model), &iter));
-    };
+    /* add only items, not toplevels */
+    if (GDL_IS_DOCK_ITEM (object))
+        *list = g_list_prepend (*list, object);
 }
 
 static void
-gdl_dock_layout_foreach_object (GdlDockObject *object,
-                                GdlDockLayout *layout)
+update_items_model (GdlDockLayout *layout)
 {
-    /* only add items to the items model (i.e. not toplevel docks) */
-    if (GDL_IS_DOCK_ITEM (object)) {
-        GtkTreeIter iter;
-        gboolean    locked;
-        gchar      *long_name;
+    GList *items, *l;
+    GtkTreeIter iter;
+    GtkListStore *store;
+    gchar *long_name;
+    gboolean locked;
+    
+    g_return_if_fail (layout != NULL);
+    g_return_if_fail (layout->_priv->items_model != NULL);
 
+    if (!layout->master)
+        return;
+    
+    /* build items list */
+    items = NULL;
+    gdl_dock_master_foreach (layout->master, (GFunc) build_list, &items);
+
+    /* walk the current model */
+    store = layout->_priv->items_model;
+    
+    /* update items model data after a layout load */
+    if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter)) {
+        gboolean valid = TRUE;
+        
+        while (valid) {
+            GdlDockItem *item;
+            
+            gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+                                COLUMN_ITEM, &item,
+                                -1);
+            if (item) {
+                /* look for the object in the items list */
+                for (l = items; l && l->data != item; l = l->next);
+
+                if (l) {
+                    /* found, update data */
+                    g_object_get (item, 
+                                  "long_name", &long_name, 
+                                  "locked", &locked, 
+                                  NULL);
+                    gtk_list_store_set (store, &iter, 
+                                        COLUMN_NAME, long_name,
+                                        COLUMN_SHOW, GDL_DOCK_OBJECT_ATTACHED (item),
+                                        COLUMN_LOCKED, locked,
+                                        -1);
+                    g_free (long_name);
+
+                    /* remove the item from the linked list and keep on walking the model */
+                    items = g_list_delete_link (items, l);
+                    valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter);
+
+                } else {
+                    /* not found, which means the item has been removed */
+                    valid = gtk_list_store_remove (store, &iter);
+                    
+                }
+
+            } else {
+                /* not a valid row */
+                valid = gtk_list_store_remove (store, &iter);
+            }
+        }
+    }
+
+    /* add any remaining objects */
+    for (l = items; l; l = l->next) {
+        GdlDockObject *object = l->data;
+        
         g_object_get (object, 
                       "long_name", &long_name, 
                       "locked", &locked, 
                       NULL);
-        gtk_list_store_append (layout->_priv->items_model, &iter);
-        gtk_list_store_set (layout->_priv->items_model, &iter, 
+        gtk_list_store_append (store, &iter);
+        gtk_list_store_set (store, &iter, 
                             COLUMN_ITEM, object,
                             COLUMN_NAME, long_name,
                             COLUMN_SHOW, GDL_DOCK_OBJECT_ATTACHED (object),
@@ -338,33 +381,26 @@ gdl_dock_layout_foreach_object (GdlDockObject *object,
                             -1);
         g_free (long_name);
     }
+    
+    g_list_free (items);
 }
 
 static void
-gdl_dock_layout_populate_models (GdlDockLayout *layout)
+update_layouts_model (GdlDockLayout *layout)
 {
     GList *items, *l;
     GtkTreeIter iter;
-
+    
     g_return_if_fail (layout != NULL);
-    g_return_if_fail (layout->_priv->items_model != NULL);
     g_return_if_fail (layout->_priv->layouts_model != NULL);
 
-    /* build items list */
-    gtk_list_store_clear (layout->_priv->items_model);
-    if (layout->master) {
-        gdl_dock_master_foreach (layout->master,
-                                 (GFunc) gdl_dock_layout_foreach_object,
-                                 (gpointer) layout);
-    };
-
     /* build layouts list */
     gtk_list_store_clear (layout->_priv->layouts_model);
     items = gdl_dock_layout_get_layouts (layout, FALSE);
     for (l = items; l; l = l->next) {
         gtk_list_store_append (layout->_priv->layouts_model, &iter);
         gtk_list_store_set (layout->_priv->layouts_model, &iter,
-                            COLUMN_NAME, l->data,
+                            COLUMN_NAME, l->data, COLUMN_EDITABLE, TRUE,
                             -1);
         g_free (l->data);
     };
@@ -374,48 +410,6 @@ gdl_dock_layout_populate_models (GdlDockLayout *layout)
 
 /* ------- UI functions & callbacks ------ */
 
-static void 
-save_layout_cb (GtkWidget *w,
-                gpointer   data)
-{
-    GdlDockLayoutUIData *ui_data = (GdlDockLayoutUIData *) data;
-
-    GdlDockLayout *layout = ui_data->layout;
-    gchar         *name;
-    
-    g_return_if_fail (layout != NULL);
-    
-    /* get the entry text and use it as a name to save the layout */
-    name = g_strdup (gtk_entry_get_text (GTK_ENTRY (ui_data->layout_entry)));
-    g_strstrip (name);
-    if (strlen (name) > 0) {
-        gboolean exists;
-
-        exists = (gdl_dock_layout_find_layout (layout, name) != NULL);
-        if (!exists && strcmp (name, DEFAULT_LAYOUT)) {
-            GtkTreeIter iter;
-
-            /* add the name to the model */
-            gtk_list_store_append (layout->_priv->layouts_model, &iter);
-            gtk_list_store_set (layout->_priv->layouts_model, &iter,
-                                COLUMN_NAME, name,
-                                -1);
-        };
-        gdl_dock_layout_save_layout (layout, name);
-
-    } else {
-        GtkWidget *error_dialog, *parent;
-        parent = gtk_widget_get_toplevel (w);
-        error_dialog = gtk_message_dialog_new (
-            parent ? GTK_WINDOW (parent) : NULL,
-            GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-            _("You must provide a name for the layout"));
-        gtk_dialog_run (GTK_DIALOG (error_dialog));
-        gtk_widget_destroy (error_dialog);
-    };
-    g_free (name);
-}
-
 static void 
 load_layout_cb (GtkWidget *w,
                 gpointer   data)
@@ -434,12 +428,8 @@ load_layout_cb (GtkWidget *w,
                             COLUMN_NAME, &name,
                             -1);
         gdl_dock_layout_load_layout (layout, name);
-        layout->_priv->changed_by_user = TRUE;
         g_free (name);
-        gdl_dock_layout_update_items_model (layout);
-        if (ui_data->layout->master)
-            g_object_notify (G_OBJECT (ui_data->layout->master), "locked");
-    };
+    }
 }
 
 static void
@@ -488,72 +478,14 @@ show_toggled_cb (GtkCellRendererToggle *renderer,
                         -1);
 
     value = !value;
-    gtk_list_store_set (layout->_priv->items_model, &iter, COLUMN_SHOW, value, -1);
     if (value)
         gdl_dock_item_show_item (item);
     else
         gdl_dock_item_hide_item (item);
 
-    layout->_priv->changed_by_user = TRUE;
     gtk_tree_path_free (path);
 }
 
-#if 0
-static void
-locked_toggled_cb (GtkCellRendererToggle *renderer,
-                   gchar                 *path_str,
-                   gpointer               data)
-{
-    GdlDockLayoutUIData *ui_data = (GdlDockLayoutUIData *) data;
-
-    GdlDockLayout *layout = ui_data->layout;
-    GtkTreeModel  *model;
-    GtkTreeIter    iter;
-    GtkTreePath   *path = gtk_tree_path_new_from_string (path_str);
-    gboolean       value;
-    GdlDockItem   *item;
-    
-    g_return_if_fail (layout != NULL);
-    
-    model = GTK_TREE_MODEL (layout->_priv->items_model);
-    gtk_tree_model_get_iter (model, &iter, path);
-    gtk_tree_model_get (model, &iter, 
-                        COLUMN_LOCKED, &value, 
-                        COLUMN_ITEM, &item, 
-                        -1);
-
-    value = !value;
-    gtk_list_store_set (layout->_priv->items_model, &iter, COLUMN_LOCKED, value, -1);
-    if (value)
-        gdl_dock_item_lock (item);
-    else
-        gdl_dock_item_unlock (item);
-
-    layout->_priv->changed_by_user = TRUE;
-    gtk_tree_path_free (path);
-}
-#endif
-
-static void
-selection_changed_cb (GtkTreeSelection *selection,
-                      gpointer          data)
-{
-    GdlDockLayoutUIData *ui_data = (GdlDockLayoutUIData *) data;
-
-    GtkTreeModel  *model;
-    GtkTreeIter    iter;
-    gchar         *name;
-
-    /* set the entry widget to the selected layout name */
-    if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-        gtk_tree_model_get (model, &iter,
-                            COLUMN_NAME, &name,
-                            -1);
-        gtk_entry_set_text (GTK_ENTRY (ui_data->layout_entry), name);
-        g_free (name);
-    };
-}
-
 static void
 all_locked_toggled_cb (GtkWidget *widget,
                        gpointer   data)
@@ -568,7 +500,6 @@ all_locked_toggled_cb (GtkWidget *widget,
 
     locked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
     g_object_set (master, "locked", locked ? 1 : 0, NULL);
-    ui_data->layout->_priv->changed_by_user = TRUE;
 }
 
 static void
@@ -582,6 +513,7 @@ layout_ui_destroyed (GtkWidget *widget,
     if (ui_data) {
         if (ui_data->layout) {
             if (ui_data->layout->master)
+                /* disconnet the notify handler */
                 g_signal_handlers_disconnect_matched (ui_data->layout->master,
                                                       G_SIGNAL_MATCH_DATA,
                                                       0, 0, NULL, NULL,
@@ -624,9 +556,8 @@ load_interface (const gchar *top_widget)
     gchar    *gui_file;
 
     /* load ui */
-    /* FIXME: set the translation domain here */
     gui_file = g_build_filename (GDL_GLADEDIR, LAYOUT_GLADE_FILE, NULL);
-    gui = glade_xml_new (gui_file, top_widget, NULL);
+    gui = glade_xml_new (gui_file, top_widget, GETTEXT_PACKAGE);
     g_free (gui_file);
     if (!gui) {
         /* FIXME: pop up an error dialog */
@@ -663,9 +594,6 @@ gdl_dock_layout_construct_items_ui (GdlDockLayout *layout)
                                (gpointer *) &ui_data->layout);
     g_object_set_data (G_OBJECT (container), "ui_data", ui_data);
     
-    /* ensure model availability */
-    gdl_dock_layout_build_models (layout);
-    
     /* get ui widget references */
     ui_data->locked_check = glade_xml_get_widget (gui, "locked_check");
     items_list = glade_xml_get_widget (gui, "items_list");
@@ -694,17 +622,6 @@ gdl_dock_layout_construct_items_ui (GdlDockLayout *layout)
                                                        NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (items_list), column);
 
-#if 0
-    renderer = gtk_cell_renderer_toggle_new ();
-    g_signal_connect (renderer, "toggled", 
-                      G_CALLBACK (locked_toggled_cb), ui_data);
-    column = gtk_tree_view_column_new_with_attributes (_("Locked"),
-                                                       renderer,
-                                                       "active", COLUMN_LOCKED,
-                                                       NULL);
-    gtk_tree_view_append_column (GTK_TREE_VIEW (items_list), column);
-#endif
-    
     renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes (_("Item"),
                                                        renderer,
@@ -720,6 +637,38 @@ gdl_dock_layout_construct_items_ui (GdlDockLayout *layout)
     return container;
 }
 
+static void
+cell_edited_cb (GtkCellRendererText *cell,
+                const gchar         *path_string,
+                const gchar         *new_text,
+                gpointer             data)
+{
+    GdlDockLayoutUIData *ui_data = data;
+    GtkTreeModel *model;
+    GtkTreePath *path;
+    GtkTreeIter iter;
+    gchar *name;
+    xmlNodePtr node;
+
+    model = GTK_TREE_MODEL (ui_data->layout->_priv->layouts_model);
+    path = gtk_tree_path_new_from_string (path_string);
+
+    gtk_tree_model_get_iter (model, &iter, path);
+    gtk_tree_model_get (model, &iter, COLUMN_NAME, &name, -1);
+
+    node = gdl_dock_layout_find_layout (ui_data->layout, name);
+    g_free (name);
+    g_return_if_fail (node != NULL);
+
+    xmlSetProp (node, NAME_ATTRIBUTE_NAME, new_text);
+    gtk_list_store_set (GTK_LIST_STORE (model), &iter, COLUMN_NAME, new_text,
+                        COLUMN_EDITABLE, TRUE, -1);
+
+    gdl_dock_layout_save_layout (ui_data->layout, new_text);
+
+    gtk_tree_path_free (path);
+}
+
 static GtkWidget *
 gdl_dock_layout_construct_layouts_ui (GdlDockLayout *layout)
 {
@@ -746,11 +695,7 @@ gdl_dock_layout_construct_layouts_ui (GdlDockLayout *layout)
                                (gpointer *) &ui_data->layout);
     g_object_set_data (G_OBJECT (container), "ui_data", ui_data);
     
-    /* ensure model availability */
-    gdl_dock_layout_build_models (layout);
-    
     /* get ui widget references */
-    ui_data->layout_entry = glade_xml_get_widget (gui, "newlayout_entry");
     layouts_list = glade_xml_get_widget (gui, "layouts_list");
 
     /* set models */
@@ -759,21 +704,17 @@ gdl_dock_layout_construct_layouts_ui (GdlDockLayout *layout)
 
     /* construct list views */
     renderer = gtk_cell_renderer_text_new ();
-    column = gtk_tree_view_column_new_with_attributes (_("Name"),
-                                                       renderer,
+    g_signal_connect (G_OBJECT (renderer), "edited",
+                      G_CALLBACK (cell_edited_cb), ui_data);
+    column = gtk_tree_view_column_new_with_attributes (_("Name"), renderer,
                                                        "text", COLUMN_NAME,
+                                                       "editable", COLUMN_EDITABLE,
                                                        NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (layouts_list), column);
 
-    /* connect signals */
     ui_data->selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (layouts_list));
-    g_signal_connect (ui_data->selection, "changed",
-                      G_CALLBACK (selection_changed_cb), ui_data);
 
-    glade_xml_signal_connect_data (gui, "on_newlayout_entry_activate",
-                                   GTK_SIGNAL_FUNC (save_layout_cb), ui_data);
-    glade_xml_signal_connect_data (gui, "on_save_button_clicked",
-                                   GTK_SIGNAL_FUNC (save_layout_cb), ui_data);
+    /* connect signals */
     glade_xml_signal_connect_data (gui, "on_load_button_clicked",
                                    GTK_SIGNAL_FUNC (load_layout_cb), ui_data);
     glade_xml_signal_connect_data (gui, "on_delete_button_clicked",
@@ -954,10 +895,11 @@ gdl_dock_layout_recursive_build (GdlDockMaster *master,
         if (object) {
             gdl_dock_object_freeze (object);
 
-            /* recurse to catch placeholders */
+            /* recurse here to catch placeholders */
             gdl_dock_layout_recursive_build (master, node, object);
             
             if (GDL_IS_DOCK_PLACEHOLDER (object))
+                /* placeholders are later attached to the parent */
                 gdl_dock_object_detach (object, FALSE);
             
             /* apply "after" parameters */
@@ -970,7 +912,7 @@ gdl_dock_layout_recursive_build (GdlDockMaster *master,
             }
             g_free (after_params);
             
-            /* add the object to the parent and recurse */
+            /* add the object to the parent */
             if (parent) {
                 if (GDL_IS_DOCK_PLACEHOLDER (object))
                     gdl_dock_placeholder_attach (GDL_DOCK_PLACEHOLDER (object),
@@ -1132,7 +1074,10 @@ gdl_dock_layout_save (GdlDockMaster *master,
     
     g_return_if_fail (master != NULL && where != NULL);
 
-    /* build the placeholder's hash */
+    /* build the placeholder's hash: the hash keeps lists of
+     * placeholders associated to each object, so that we can save the
+     * placeholders when we are saving the object (since placeholders
+     * don't show up in the normal widget hierarchy) */
     placeholders = g_hash_table_new_full (g_direct_hash, g_direct_equal,
                                           NULL, (GDestroyNotify) g_list_free);
     gdl_dock_master_foreach (master, (GFunc) add_placeholder, placeholders);
@@ -1180,8 +1125,13 @@ static void
 gdl_dock_layout_layout_changed_cb (GdlDockMaster *master,
                                    GdlDockLayout *layout)
 {
-    if (!layout->_priv->idle_save_pending)
+    /* update model */
+    update_items_model (layout);
+
+    if (!layout->_priv->idle_save_pending) {
         g_idle_add ((GSourceFunc) gdl_dock_layout_idle_save, layout);
+        layout->_priv->idle_save_pending = TRUE;
+    }
 }
 
 void
@@ -1197,7 +1147,7 @@ gdl_dock_layout_attach (GdlDockLayout *layout,
         g_object_unref (layout->master);
     }
     
-    /* FIXME: destroy and create models */
+    gtk_list_store_clear (layout->_priv->items_model);
     
     layout->master = master;
     if (layout->master) {
@@ -1206,6 +1156,8 @@ gdl_dock_layout_attach (GdlDockLayout *layout,
                           (GCallback) gdl_dock_layout_layout_changed_cb,
                           layout);
     }
+
+    update_items_model (layout);
 }
 
 gboolean
@@ -1269,7 +1221,6 @@ gdl_dock_layout_save_layout (GdlDockLayout *layout,
 
     /* save the layout */
     gdl_dock_layout_save (layout->master, node);
-    layout->_priv->changed_by_user = FALSE;
     layout->dirty = TRUE;
     g_object_notify (G_OBJECT (layout), "dirty");
 }
@@ -1322,19 +1273,10 @@ gdl_dock_layout_run_manager (GdlDockLayout *layout)
                                           NULL);
 
     gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 300);
-
     gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), container);
     
-    /* fill in data */
-    gdl_dock_layout_populate_models (layout);
-
     gtk_dialog_run (GTK_DIALOG (dialog));
 
-    if (layout->_priv->changed_by_user) {
-        /* save the default (current) layout */
-        gdl_dock_layout_save_layout (layout, NULL);
-    };
-
     gtk_widget_destroy (dialog);
 }
 
@@ -1358,6 +1300,7 @@ gdl_dock_layout_load_from_file (GdlDockLayout *layout,
             xmlNodePtr root = layout->_priv->doc->children;
             /* minimum validation: test the root element */
             if (root && !strcmp (root->name, ROOT_ELEMENT)) {
+                update_layouts_model (layout);
                 retval = TRUE;
             } else {
                 xmlFreeDoc (layout->_priv->doc);
@@ -1443,12 +1386,6 @@ gdl_dock_layout_get_ui (GdlDockLayout *layout)
     g_return_val_if_fail (layout != NULL, NULL);
     ui = gdl_dock_layout_construct_ui (layout);
 
-    /* FIXME: this shouldn't be here.  Instead populate models should
-       change when an item is added/removed from the dock master, and
-       when gdl_dock_layout_load_from_file is called.  And do it in an
-       idle handler */
-    gdl_dock_layout_populate_models (layout);
-
     return ui;
 }
 
@@ -1460,9 +1397,6 @@ gdl_dock_layout_get_items_ui (GdlDockLayout *layout)
     g_return_val_if_fail (layout != NULL, NULL);
     ui = gdl_dock_layout_construct_items_ui (layout);
 
-    /* FIXME: same case as gdl_dock_layout_get_ui */
-    gdl_dock_layout_populate_models (layout);
-
     return ui;
 }
 
@@ -1474,10 +1408,5 @@ gdl_dock_layout_get_layouts_ui (GdlDockLayout *layout)
     g_return_val_if_fail (layout != NULL, NULL);
     ui = gdl_dock_layout_construct_layouts_ui (layout);
 
-    /* FIXME: same case as gdl_dock_layout_get_ui */
-    gdl_dock_layout_populate_models (layout);
-
     return ui;
 }
-
-
