@@ -22,14 +22,21 @@
  * Boston, MA 02111-1307, USA.  
  */
 
-#include <libgnome/gnome-macros.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "gdl-i18n.h"
 
 #include "gdl-tools.h"
 #include "gdl-dock-placeholder.h"
 #include "gdl-dock-item.h"
+#include "gdl-dock-master.h"
 #include "libgdltypebuiltins.h"
 
 
+#undef PLACEHOLDER_DEBUG
+
 /* ----- Private prototypes ----- */
 
 static void     gdl_dock_placeholder_class_init     (GdlDockPlaceholderClass *klass);
@@ -96,8 +103,8 @@ struct _GdlDockPlaceholderPrivate {
 
 /* ----- Private interface ----- */
 
-GNOME_CLASS_BOILERPLATE (GdlDockPlaceholder, gdl_dock_placeholder,
-			 GdlDockObject, GDL_TYPE_DOCK_OBJECT);
+GDL_CLASS_BOILERPLATE (GdlDockPlaceholder, gdl_dock_placeholder,
+                       GdlDockObject, GDL_TYPE_DOCK_OBJECT);
 
 static void 
 gdl_dock_placeholder_class_init (GdlDockPlaceholderClass *klass)
@@ -234,7 +241,7 @@ gdl_dock_placeholder_destroy (GtkObject *object)
         ph->_priv = NULL;
     }
 
-    GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+    GDL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void 
@@ -306,10 +313,10 @@ gdl_dock_placeholder_dock (GdlDockObject    *object,
     }
 }
 
+#ifdef PLACEHOLDER_DEBUG
 static void
 print_placement_stack (GdlDockPlaceholder *ph)
 {
-#if 0
     GSList *s = ph->_priv->placement_stack;
     GEnumClass *enum_class = G_ENUM_CLASS (g_type_class_ref (GDL_TYPE_DOCK_PLACEMENT));
     GEnumValue *enum_value;
@@ -328,8 +335,8 @@ print_placement_stack (GdlDockPlaceholder *ph)
     
     g_string_free (message, TRUE);
     g_type_class_unref (enum_class);
-#endif
 }
+#endif
 
 static void 
 gdl_dock_placeholder_present (GdlDockObject *object,
@@ -455,7 +462,9 @@ detach_cb (GdlDockObject *object,
     if (new_host)
         connect_host (ph, new_host);
 
+#ifdef PLACEHOLDER_DEBUG
     print_placement_stack (ph);
+#endif
 }
 
 /**
@@ -532,7 +541,9 @@ dock_cb (GdlDockObject    *object,
             }
         }
     }
+#ifdef PLACEHOLDER_DEBUG
     print_placement_stack (ph);
+#endif
 }
 
 static void
